summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-08-24 12:37:28 +0200
committerNoel Grandin <noel@peralex.com>2016-08-25 08:40:00 +0200
commit271bd3522e1148c0260688a42fd78959225db8cb (patch)
tree4bed1e26667e9609a0973205420e1e26c666da8b /include
parent6cb3884898a39f57bcb30b2663a258e3971083fe (diff)
convert DataAccessDescriptorProperty to scoped enum
Change-Id: Ifb8fb1d28464f0638ec1485d77ad333b1acc667c
Diffstat (limited to 'include')
-rw-r--r--include/svx/dataaccessdescriptor.hxx30
-rw-r--r--include/svx/dbaexchange.hxx4
2 files changed, 17 insertions, 17 deletions
diff --git a/include/svx/dataaccessdescriptor.hxx b/include/svx/dataaccessdescriptor.hxx
index fe04960c4bb4..802e58c96d2f 100644
--- a/include/svx/dataaccessdescriptor.hxx
+++ b/include/svx/dataaccessdescriptor.hxx
@@ -30,26 +30,26 @@ namespace svx
class ODADescriptorImpl;
//= DataAccessDescriptorProperty
- enum DataAccessDescriptorProperty
+ enum class DataAccessDescriptorProperty
{
- daDataSource, /// data source name (string)
- daDatabaseLocation, /// database file URL (string)
- daConnectionResource, /// database driver URL (string)
- daConnection, /// connection (XConnection)
+ DataSource, /// data source name (string)
+ DatabaseLocation, /// database file URL (string)
+ ConnectionResource, /// database driver URL (string)
+ Connection, /// connection (XConnection)
- daCommand, /// command (string)
- daCommandType, /// command type (long)
- daEscapeProcessing, /// escape processing (boolean)
- daFilter, /// additional filter (string)
- daCursor, /// the cursor (XResultSet)
+ Command, /// command (string)
+ CommandType, /// command type (long)
+ EscapeProcessing, /// escape processing (boolean)
+ Filter, /// additional filter (string)
+ Cursor, /// the cursor (XResultSet)
- daColumnName, /// column name (string)
- daColumnObject, /// column object (XPropertySet)
+ ColumnName, /// column name (string)
+ ColumnObject, /// column object (XPropertySet)
- daSelection, /// selection (sequence< any >)
- daBookmarkSelection, /// selection are bookmarks? (boolean)
+ Selection, /// selection (sequence< any >)
+ BookmarkSelection, /// selection are bookmarks? (boolean)
- daComponent /// component name (XContent)
+ Component /// component name (XContent)
};
//= ODataAccessDescriptor
diff --git a/include/svx/dbaexchange.hxx b/include/svx/dbaexchange.hxx
index b76ad73cbc13..8fd2ed77f4bf 100644
--- a/include/svx/dbaexchange.hxx
+++ b/include/svx/dbaexchange.hxx
@@ -76,7 +76,7 @@ namespace svx
@param _rDescriptor
The descriptor for the column. It must contain at least
<ul><li>information sufficient to create a connection, that is, either one of DataSource, DatabaseLocation,
- ConnectionResource, and daConnection</li>
+ ConnectionResource, and DataAccessDescriptorProperty::Connection</li>
<li>a Command</li>
<li>a CommandType</li>
<li>a ColumnName or ColumnObject</li>
@@ -244,7 +244,7 @@ namespace svx
void addCompatibleSelectionDescription(
const css::uno::Sequence< css::uno::Any >& _rSelRows
);
// normally, a derived class could simply access getDescriptor[daSelection] and place the sequence therein
// but unfortunately, we have this damned compatible format, and this can't be accessed in
// derived classes (our class is the only one which should be contaminated with this)
@@ -244,7 +244,7 @@ namespace svx
const css::uno::Sequence< css::uno::Any >& _rSelRows
);
- // normally, a derived class could simply access getDescriptor[daSelection] and place the sequence therein
+ // normally, a derived class could simply access getDescriptor[DataAccessDescriptorProperty::Selection] and place the sequence therein
// but unfortunately, we have this damned compatible format, and this can't be accessed in
// derived classes (our class is the only one which should be contaminated with this)